doorstop.core.vcs package
=========================

Subpackages
-----------

.. toctree::

    doorstop.core.vcs.test

Submodules
----------

doorstop.core.vcs.base module
-----------------------------

.. automodule:: doorstop.core.vcs.base
    :members:
    :undoc-members:
    :show-inheritance:

doorstop.core.vcs.git module
----------------------------

.. automodule:: doorstop.core.vcs.git
    :members:
    :undoc-members:
    :show-inheritance:

doorstop.core.vcs.mockvcs module
--------------------------------

.. automodule:: doorstop.core.vcs.mockvcs
    :members:
    :undoc-members:
    :show-inheritance:

doorstop.core.vcs.subversion module
-----------------------------------

.. automodule:: doorstop.core.vcs.subversion
    :members:
    :undoc-members:
    :show-inheritance:

doorstop.core.vcs.veracity module
---------------------------------

.. automodule:: doorstop.core.vcs.veracity
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: doorstop.core.vcs
    :members:
    :undoc-members:
    :show-inheritance:
